--[[ $Id$
   Copyright (c) Brett England, 2013
   Copyright (c) Mark Baldwin, 2013

   No commercial use.
   No redistribution at profit.
   All derivative work must retain this message and
   acknowledge the work of the original author.
--]]



local bsc = require "bsc"
--local xap = require "xap"
local widget = require "widget" 
local storyboard = require "storyboard"
local ui = require "ui"
local scene = storyboard.newScene()

function scene:createScene( event )
	local group = self.view
	
	local background = display.newImageRect( "background.png", 800, 480)
	background.x = display.contentWidth/2
	background.y = display.contentHeight/2 
	group:insert( background )


	local img_floorplan = display.newImageRect( "FloorPlan.png", 640, 400)
	img_floorplan.x = display.contentWidth/2 +90
	img_floorplan.y = display.contentHeight/2 - 20
	group:insert( img_floorplan )

		-- GRID helper functions
	function toggle(v, xpos, ypos)
		v.x = xpos
		v.y = ypos
		v.size = v.size or 20
		v.default = v.default or "assets/glossy_button_red.png"
		v.on = v.on or "assets/glossy_button_green.png"
		return bsc.newToggle(v)
	end

	-- Its an output.state endpoint but we don't to allow user control of it.
	-- so we WIPE off the touch handler of the button.
	function readonlyToggle(v, xpos, ypos)
		local btn = toggle(v, xpos, ypos)
		btn.touch = nil
		return btn
	end
	
	function button(v, xpos, ypos)
		return bsc.newButton {
				defaultSrc = v.icon, defaultX = 80, defaultY = 80, -- img, width, height
				x=xpos, y=ypos, -- position
				size=20, -- font size
				offset=15,
				label={text=v.label, offset=-5, size=10, textColor={ 0, 0, 0, 255 }},
				textColor={ 0, 0, 0, 255 }, -- r,g,b,a
				xapSource=v.xapSource,
		}
	end

	-- A Label is a button that is does not accept user press events.
	function label(v, xpos, ypos)
		return bsc.newButton {
				defaultSrc = v.icon, defaultX = 80, defaultY = 80, -- img, width, height
				x=xpos, y=ypos, -- position
				size=20, -- font size
				offset=15,
				label={text=v.label, offset=-5, size=10, textColor={ 0, 0, 0, 255 }},
				textColor={ 0, 0, 0, 255 }, -- r,g,b,a
				xapSource=v.xapSource,
				readOnly=true
		}
	end


	local grid = {
	{
		  {c=ui.newLabel, bounds={0,0,800,50}, text="  Summary", align="left", size=20}
	},
    { -- ROW 1
		{c=label, icon="powerW.png", label="WholeHouse", xapSource='dbzoo.livebox.currentcost:ch.1'},
		{c=label, icon="degC.png", label="Lounge", xapSource='dbzoo.livebox.jeenode:livingroom.temp'},
	},
	{ -- ROW 2
		{c=label, icon="degC.png", label="Outside", xapSource='dbzoo.livebox.jeenode:gas-monitor.temp'},
		{},
			
	},
	
	}
			
	-- Render grid
	local ypos = 0, xpos
	for _,r in ipairs(grid) do		
		xpos=50
		for _,v in pairs(r) do
			if v.c then
				group:insert(v.c(v, xpos, ypos)) --mod here
			end
			xpos = xpos + 80
		end
		ypos = ypos + 80
	end

	local function onButtonRelease( event )
		local phase = event.phase 
		local target = event.target
		if "ended" == phase then
			--print( "You pressed and released the "..target.id.." button!" )
			storyboard.gotoScene( target.id )
		end
	end


	local lounge = widget.newButton{--lounge
	
			id = "lounge",
			label = "Living Room",
			labelColor = { default={ 65 }, over={ 0 } },
			font = "Helvetica-Bold",
			fontSize = 10,
			top = 260,
			left = 340,
			--defaultFile = "conservatory.png",
			--overFile = "conservatory.png",
			width = 85,
			height = 40,
			onRelease = onButtonRelease,
			emboss = true
	}

	
	local kitchen = widget.newButton{--kitchen

			id = "kitchen",
			label = "Kitchen",
			labelColor = { default={ 65 }, over={ 0 } },
			font = "Helvetica-Bold",
			fontSize = 10,
			top = 80,
			left = 285,
			--defaultFile = "kitchen.png",
			--overFile = "kitchen.png",
			width = 85,
			height = 40,
			onRelease = onButtonRelease,
			emboss = true
	}


	
	-- Insert the button into a group:
	group:insert( lounge )
	group:insert( kitchen )

end

-- Called immediately after scene has moved onscreen:
function scene:enterScene( event )
	local group = self.view
	--storyboard.removeScene(storyboard.getPrevious())
	--storyboard.removeScene("view2")
	-- Do nothing
end

-- Called when scene is about to move offscreen:
function scene:exitScene( event )
	local group = self.view
	storyboard.removeScene(storyboard.getCurrentSceneName())
	
end

-- If scene's view is removed, scene:destroyScene() will be called just prior to:
function scene:destroyScene( event )
	local group = self.view
	
	-- INSERT code here (e.g. remove listeners, remove widgets, save state variables, etc.)
	
end

-----------------------------------------------------------------------------------------
-- END OF YOUR IMPLEMENTATION
-----------------------------------------------------------------------------------------

-- "createScene" event is dispatched if scene's view does not exist
scene:addEventListener( "createScene", scene )

-- "enterScene" event is dispatched whenever scene transition has finished
scene:addEventListener( "enterScene", scene )

-- "exitScene" event is dispatched whenever before next scene's transition begins
scene:addEventListener( "exitScene", scene )

-- "destroyScene" event is dispatched before view is unloaded, which can be
-- automatically unloaded in low memory situations, or explicitly via a call to
-- storyboard.purgeScene() or storyboard.removeScene().
scene:addEventListener( "destroyScene", scene )

-----------------------------------------------------------------------------------------

return scene
